==> wls-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsForeignJmsConnectionFactoryToWlsClusterMapper.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.MappingAgnosticStepGeneratingMapper;
import com.xebialabs.deployit.plugin.wls.ci.WlsCluster;
import com.xebialabs.deployit.plugin.wls.ci.WlsForeignJmsConnectionFactory;
import com.xebialabs.deployit.plugin.wls.step.CreateWlsForeignJmsConnectionFactoryStep;
import com.xebialabs.deployit.plugin.wls.step.DestroyWlsForeignJmsConnectionFactoryStep;

public class WlsForeignJmsConnectionFactoryToWlsClusterMapper extends MappingAgnosticStepGeneratingMapper<WlsForeignJmsConnectionFactory, WlsCluster> {

	public WlsForeignJmsConnectionFactoryToWlsClusterMapper(Change<Deployment> change) {
		super(change);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(WlsForeignJmsConnectionFactory newSource, WlsCluster newTarget, List<Step> steps) {
		steps.add(new CreateWlsForeignJmsConnectionFactoryStep(newTarget.getDomain(), newSource));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(WlsForeignJmsConnectionFactory oldSource, WlsCluster oldTarget, List<Step> steps) {
		steps.add(new DestroyWlsForeignJmsConnectionFactoryStep(oldTarget.getDomain(), oldSource));
	}

}

==> wls-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsForeignJmsConnectionFactoryToWlsClusterMapper.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.MappingAgnosticStepGeneratingMapper;
import com.xebialabs.deployit.plugin.wls.ci.WlsCluster;
import com.xebialabs.deployit.plugin.wls.ci.WlsForeignJmsConnectionFactory;
import com.xebialabs.deployit.plugin.wls.step.CreateWlsForeignJmsConnectionFactoryStep;
import com.xebialabs.deployit.plugin.wls.step.DestroyWlsForeignJmsConnectionFactoryStep;

public class WlsForeignJmsConnectionFactoryToWlsClusterMapper extends MappingAgnosticStepGeneratingMapper<WlsForeignJmsConnectionFactory, WlsCluster> {

	public WlsForeignJmsConnectionFactoryToWlsClusterMapper(Change<Deployment> change) {
		super(change);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(WlsForeignJmsConnectionFactory foreignJmsConnectionFactory, WlsCluster cluster, List<Step> steps) {
		steps.add(new CreateWlsForeignJmsConnectionFactoryStep(cluster.getDomain(), JmsMapperUtils.getJmsModuleName(change, cluster), foreignJmsConnectionFactory));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(WlsForeignJmsConnectionFactory foreignJmsConnectionFactory, WlsCluster cluster, List<Step> steps) {
		steps.add(new DestroyWlsForeignJmsConnectionFactoryStep(cluster.getDomain(), JmsMapperUtils.getJmsModuleName(change, cluster), foreignJmsConnectionFactory));
	}

}
